from sys import exit
from onepassword_local_search.exceptions.ManagedException import ManagedException
from onepassword_local_search.OnePassword import OnePassword
from argparse import ArgumentParser, Namespace
import sys


class CliSimple:

    args: Namespace
    command: str

    def __init__(self, *args):

        parser = ArgumentParser()
        subparsers = parser.add_subparsers(dest='command')

        action_get = subparsers.add_parser('get')
        action_get.add_argument('uuid', help='uuid to fetch')
        action_get.add_argument('field', help='field to retrieve', nargs='?', default=None)
        action_get.add_argument('--use-custom-uuid', help='use custom UUID mapping', nargs='?', default=False, const=True)

        action_list = subparsers.add_parser('list')
        action_list.add_argument('--format', help='custom format string')
        action_list.add_argument('--filter', help='filter over title entry')

        action_is_authenticated = subparsers.add_parser('is-authenticated')

        action_version = subparsers.add_parser('version')

        action_update_mapping = subparsers.add_parser('mapping')
        action_update_mapping.add_argument('subcommand', help='update or list', choices=['list', 'update'])

        self.args = parser.parse_args(args[1:])

    def run(self):
        try:
            app = OnePassword(self.args)
            return getattr(app, self.args.command.replace('-', '_'))()
        except ManagedException as e:
            exit(e.args[0])
        except (BrokenPipeError, IOError):
            sys.stderr.close()
            pass






from onepassword_local_search.models.Cipher import Cipher
from json import dumps as json_dumps
from onepassword_local_search.exceptions.ManagedException import ManagedException


class Item:

    id: str
    uuid: str
    vault_id: str
    encryptedOverview: Cipher
    encryptedDetails: Cipher
    overview: dict
    details: dict

    def __init__(self, row):
        self.id = row['id']
        self.uuid = row['uuid']
        self.vaultId = row['vault_id']
        self.encryptedOverview = Cipher(row['overview'])
        self.encryptedDetails = Cipher(row['details'])

    def get(self, field=None, strict=True):
        if field is None:
            self.__delattr__('encryptedOverview')
            self.__delattr__('encryptedDetails')
            return self.output(self.__dict__)

        path = field.split(';;')
        out = None

        if field in ['title', 'url']:
            out = self.overview.get(field)
        elif field in ['username', 'password'] and (out is None or out == ''):
            out = self.details.get(field)
            if out is None:
                out = self._get_details_field(field)
        elif field == 'notesPlain' and (out is None or out == ''):
            out = self.details.get(field)
        elif hasattr(self, field) and (out is None or out == ''):
            out = self.__getattribute__(field)
        elif len(path) > 1 and (out is None or out == ''):
            for section in self.details.get('sections'):
                if section['title'] == path[0]:
                    for f in section['fields']:
                        if f['t'] == path[1] or f['n'] == path[1]:
                            out = f['v']
                            break
        if out is None and self.details.get('sections'):
            # Fallback: search fieldName is all sections
            for section in self.details.get('sections'):
                if section.get('fields'):
                    for f in section['fields']:
                        if f['t'] == field or f['n'] == field:
                            out = f['v']
                            break

        if strict and out is None:
            raise ManagedException('Unable to find field %s of item %s ' % (field, self.uuid))
        elif not strict and out is None:
            return ''

        return self.output(out)

    def _get_details_field(self, field):
        if self.details.get('fields'):
            for f in self.details.get('fields'):
                if f['name'] == field:
                    return f['value']
        return None

    def output(self, content):
        out_type = type(content).__name__
        if out_type in ['str', 'int']:
            return content
        else:
            return json_dumps(content)



class ManagedException(Exception):
    def __init__(self, *args, **kwargs):
        Exception.__init__(self, *args, **kwargs)


class ProperExit(Exception):
    def __init__(self, *args, message='', **kwargs) :
        Exception.__init__(self, *args, **kwargs)


from onepassword_local_search.services.StorageService import StorageService
from onepassword_local_search.services.CryptoService import CryptoService
from onepassword_local_search.models.Item import Item
from onepassword_local_search.services.ConfigFileService import ConfigFileService
from re import sub as re_sub
import string
from argparse import Namespace


class OnePassword:

    args: Namespace
    storageService: StorageService
    cryptoService: CryptoService
    configFileService: ConfigFileService
    useCustomUUIDMapping: bool = False

    def __init__(self, args):
        self.args = args
        if 'use_custom_uuid' in self.args.__dict__.keys():
            self.useCustomUUIDMapping = self.args.use_custom_uuid
        self.storageService = StorageService(self.useCustomUUIDMapping)
        self.configFileService = ConfigFileService()
        self.cryptoService = CryptoService(self.storageService, self.configFileService)
        if self.useCustomUUIDMapping:
            self._ensure_uuid_mapping_has_values()

    def _ensure_uuid_mapping_has_values(self):
        if not self.storageService.uuid_mapping_has_entries():
            self.mapping_update()

    def get(self):
        encrypted_item = Item(self.storageService.get_item_by_uuid(self.args.uuid, self.useCustomUUIDMapping))
        item = self.cryptoService.decrypt_item(encrypted_item)
        decrypted_field = item.get(self.args.field)
        print(decrypted_field, end='')
        return decrypted_field

    def get_items(self, filter):
        items = []
        for item in self.storageService.list():
            decrypted_item = self.cryptoService.decrypt_item(Item(item))
            if filter is None or filter in decrypted_item.overview['title']:
                items.append(decrypted_item)
        return items

    def list(self):
        class SimpleFormatter(string.Formatter):
            def get_value(self, key, args, kwargs):
                return item.get(key, strict=False)
        list_format = self.args.format if self.args.format else '{uuid} {title}'
        sf = SimpleFormatter()
        for item in self.get_items(self.args.filter):
            print(sf.format(list_format, item).strip())

    def mapping(self):
        self.storageService.checks_for_uuid_mapping()
        return getattr(self, 'mapping_' + self.args.subcommand)()

    def mapping_update(self):
        self.storageService.truncate_uuid_mapping_table()
        for item in self.storageService.list():
            decrypted_item = self.cryptoService.decrypt_item(Item(item))
            custom_uuid = decrypted_item.get('UUID', strict=False)
            if custom_uuid:
                self.storageService.add_uuid_mapping(custom_uuid, decrypted_item.uuid)
        self.storageService.con.commit()

    def mapping_list(self):
        for item in self.storageService.list_mapping():
            print("%s <-> %s" % (item['op_uuid'], item['custom_uuid']))

    @staticmethod
    def version():
        from .__version__ import __version__
        print('Version: ' + __version__)

    def is_authenticated(self):
        return self.cryptoService.is_authenticated()



from os import environ, path as os_path
from sqlite3 import Connection, Cursor, connect as sqlite3_connect
from onepassword_local_search.exceptions.ManagedException import ManagedException
from platform import system


class StorageService:

    app_path: str
    con: Connection
    cur: Cursor
    uuid_mapping_table_name: str = 'uuid_mapping'
    use_custom_uuid_mapping: bool = False

    def __init__(self, use_custom_uuid_mapping=False):
        self.use_custom_uuid_mapping = use_custom_uuid_mapping
        self.con = self.set_database_connexion()
        self.cur = self.con.cursor()
        if use_custom_uuid_mapping:
            self.checks_for_uuid_mapping()

    def checks_for_uuid_mapping(self):
        if not self._has_table(StorageService.uuid_mapping_table_name):
            self.create_uuid_mapping_table()

    @staticmethod
    def _dict_factory(cursor, row):
        d = {}
        for idx, col in enumerate(cursor.description):
            d[col[0]] = row[idx]
        return d

    def _has_table(self, table_name):
        query = "SELECT name from sqlite_master WHERE type='table' AND name='%s';" % table_name
        return self.con.execute(query).fetchone()

    def create_uuid_mapping_table(self):
        request = """
                    BEGIN;
                    CREATE TABLE IF NOT EXISTS %s (                        
                        op_uuid TEXT,
                        custom_uuid TEXT,
                        PRIMARY KEY (op_uuid, custom_uuid),
                        FOREIGN KEY (op_uuid) REFERENCES items (uuid)
                        ON DELETE CASCADE
                    );
                    CREATE INDEX idx_%s_custom_uuid ON %s (custom_uuid);
                    COMMIT;
                  """ % (StorageService.uuid_mapping_table_name, StorageService.uuid_mapping_table_name, StorageService.uuid_mapping_table_name)
        return self.con.executescript(request)

    def truncate_uuid_mapping_table(self):
        request = """
                    BEGIN;
                    DELETE FROM uuid_mapping; 
                    COMMIT;
                  """
        return self.con.executescript(request)

    def uuid_mapping_has_entries(self):
        query = "SELECT COUNT(custom_uuid) as nb FROM %s" % StorageService.uuid_mapping_table_name
        return self.cur.execute(query).fetchone()['nb']

    def get_item_by_uuid(self, uuid, use_custom_uuid_mapping=False):
        if use_custom_uuid_mapping:
            query = "SELECT * FROM items WHERE uuid = (SELECT op_uuid FROM %s WHERE custom_uuid='%s')" % (StorageService.uuid_mapping_table_name, uuid)
        else:
            query = "SELECT * FROM items WHERE uuid = '%s'" % uuid
        res = self.cur.execute(query).fetchone()
        if res is None:
            raise ManagedException('Unable to find item with uuid: %s' % uuid)
        return res

    def list_mapping(self):
        query = "SELECT * FROM %s;" % StorageService.uuid_mapping_table_name
        return self.cur.execute(query).fetchall()

    def add_uuid_mapping(self, custom_uuid, op_uuid):
        request = "INSERT INTO %s VALUES ('%s','%s')" % (StorageService.uuid_mapping_table_name, op_uuid, custom_uuid)
        return self.cur.execute(request)

    @staticmethod
    def guess_database_path():
        if environ.get('ONEPASSWORD_LOCAL_DATABASE_PATH'):
            path = environ.get('ONEPASSWORD_LOCAL_DATABASE_PATH')
        elif system() == 'Darwin':
            path = os_path.join(environ.get('HOME'), 'Library', 'Group Containers', '2BUA8C4S2C.com.agilebits', 'Library', 'Application Support', '1Password', 'Data', 'B5.sqlite')
        elif system() == 'Windows':
            path = os_path.join(environ.get('LocalAppData'), '1password', 'data', '1Password10.sqlite')
        else:
            path = None

        if path is not None and path != '':
            return path
        else:
            raise Exception('Unable to determine 1Password local database patsh')

    def set_database_connexion(self):
        path = os_path.expandvars(self.guess_database_path())
        if not os_path.isfile(path):
            raise Exception('Database file not found at ' + path)
        con = sqlite3_connect(path)
        con.row_factory = self._dict_factory
        return con

    def get_account_id_from_user_uuid(self, user_uuid):
        query = "select id from accounts where user_uuid='%s';" % user_uuid
        return self.cur.execute(query).fetchone()['id']

    def get_encrypted_symmetric_key(self, account_id):
        query = "select enc_sym_key from keysets where encrypted_by='mp' and account_id=%s;" % account_id
        return self.cur.execute(query).fetchone()['enc_sym_key']

    def get_account_key(self, account_id):
        query = "select enc_login from accounts where id=%s" % account_id
        return self.cur.execute(query).fetchone()['enc_login']

    def get_encrypted_private_key(self, account_id):
        query = "select enc_pri_key from keysets where encrypted_by='mp' and account_id=%s;" % account_id
        return self.cur.execute(query).fetchone()['enc_pri_key']

    def get_encrypted_vault_key(self, vault_id, account_id):
        query = "select enc_vault_key from vault_access where id=%s and account_id=%s;" % (vault_id, account_id)
        return self.cur.execute(query).fetchone()['enc_vault_key']

    def list(self):
        query = "select * from items where trashed = 0"
        return self.cur.execute(query).fetchall()


import pytest
from onepassword_local_search.CliSimple import CliSimple
from onepassword_local_search.__version__ import __version__
from onepassword_local_search.tests.fixtures_common import common_data, no_op_session, op_session

nl = common_data("nl")


@pytest.fixture
def cli_version():
    return CliSimple('script', 'version')


@pytest.mark.usefixtures("no_op_session")
def test_version(cli_version, capsys):
    cli_version.run()
    std = capsys.readouterr()
    assert std.out == 'Version: ' + __version__ + nl


@pytest.fixture
def cli_get_uuid():
    return CliSimple('script', 'get', common_data('item_uuid'), 'password')


@pytest.mark.usefixtures("no_op_session")
def test_get_uuid(cli_get_uuid, capsys):
    with pytest.raises(SystemExit) as exit_code:
        cli_get_uuid.run()
    std = capsys.readouterr()
    assert std.out.find('OP_SESSION_team is not set') != -1
    assert exit_code.type == SystemExit
    assert exit_code.value.code == 1


@pytest.mark.usefixtures("op_session")
def test_get_title(capsys):
    CliSimple('script', 'get', common_data('item_uuid'), 'title').run()
    std = capsys.readouterr()
    assert std.out == 'Software licence'


@pytest.mark.usefixtures("op_session")
def test_get_login_title(capsys):
    CliSimple('script', 'get', common_data('login_uuid'), 'title').run()
    std = capsys.readouterr()
    assert std.out == 'Connexion'


@pytest.mark.usefixtures("op_session")
def test_get_login_uuid(capsys):
    CliSimple('script', 'get', common_data('login_uuid'), 'uuid').run()
    std = capsys.readouterr()
    assert std.out == 'zzfmhu2j7ajq55mmpm3ihs3oqy'


@pytest.mark.usefixtures("op_session")
def test_get_login_url(capsys):
    CliSimple('script', 'get', common_data('login_uuid'), 'url').run()
    std = capsys.readouterr()
    assert std.out == 'https://site1.com'


@pytest.mark.usefixtures("op_session")
def test_get_login_username(capsys):
    CliSimple('script', 'get', common_data('login_uuid'), 'username').run()
    std = capsys.readouterr()
    assert std.out == 'username'


@pytest.mark.usefixtures("op_session")
def test_get_login_username(capsys):
    CliSimple('script', 'get', common_data('login_uuid'), 'password').run()
    std = capsys.readouterr()
    assert std.out == 'password'


@pytest.mark.usefixtures("op_session")
def test_get_login_username(capsys):
    CliSimple('script', 'get', common_data('login_uuid'), 'Section1;;Section1Field1').run()
    std = capsys.readouterr()
    assert std.out == 'Section1Field1Value'


@pytest.mark.usefixtures("op_session")
def test_get_login_username(capsys):
    CliSimple('script', 'get', common_data('login_uuid'), 'Section2;;Section2Field2').run()
    std = capsys.readouterr()
    assert std.out == 'Section2Field2Value'


@pytest.mark.usefixtures("op_session")
def test_list(capsys):
    CliSimple('script', 'list').run()
    std = capsys.readouterr()
    assert '\n'.join(sorted(std.out.split('\n'))) == '''
5pwta5jhf5fhj5wzfek4sb22ve Mickaël
a53bppwuhi65b2e34g45fjyfwu Email account
akvb4bbdequd3z6tuorl44btqm Bienvenue dans 1Password !
e25haqmocd5ifiymorfzwxnzry Software licence
hujxh3pryngc7du3owbkwwuh3i test
mvkzp2v2myljdqzxcv5736optu Secure Note
n3iopimevz3pddels3dgfwyp2a Simple Password
ngkzmk54qoltpdoseqspma4tba File certificate
smeg46sk3agiee4cfinvpf7z4u Database
w2euij3m4zhqa5opftnthe5d4q Server
zzfmhu2j7ajq55mmpm3ihs3oqy Connexion'''


@pytest.mark.usefixtures("op_session")
def test_list_custom_field(capsys):
    CliSimple('script', 'list', '--format={uuid} {username} {password}').run()
    std = capsys.readouterr()
    assert '\n'.join(sorted(std.out.split('\n'))) == '''
5pwta5jhf5fhj5wzfek4sb22ve
a53bppwuhi65b2e34g45fjyfwu
akvb4bbdequd3z6tuorl44btqm
e25haqmocd5ifiymorfzwxnzry
hujxh3pryngc7du3owbkwwuh3i
mvkzp2v2myljdqzxcv5736optu
n3iopimevz3pddels3dgfwyp2a  password
ngkzmk54qoltpdoseqspma4tba
smeg46sk3agiee4cfinvpf7z4u username password
w2euij3m4zhqa5opftnthe5d4q username password
zzfmhu2j7ajq55mmpm3ihs3oqy username password'''


@pytest.mark.usefixtures("op_session")
def test_list_custom_uuid(capsys):
    CliSimple('script', 'list', '--format={uuid} {UUID}').run()
    std = capsys.readouterr()
    assert '\n'.join(sorted(std.out.split('\n'))) == '''
5pwta5jhf5fhj5wzfek4sb22ve
a53bppwuhi65b2e34g45fjyfwu c08335ad-5f93-471f-8605-2500ae4b9ce1
akvb4bbdequd3z6tuorl44btqm
e25haqmocd5ifiymorfzwxnzry 84103613-2483-430d-8e74-bc72036f378c
hujxh3pryngc7du3owbkwwuh3i
mvkzp2v2myljdqzxcv5736optu b325bc32-7c2d-4107-bc2c-73777cb3e33a
n3iopimevz3pddels3dgfwyp2a 41495d3a-9b1a-4ce6-9bbd-82fbc4e538a9
ngkzmk54qoltpdoseqspma4tba 4dc2d37a-bc4e-47a8-a96b-206048b7d7d5
smeg46sk3agiee4cfinvpf7z4u 6bf1b272-f35d-4087-808f-253909fb0c91
w2euij3m4zhqa5opftnthe5d4q f544c30d-612f-4c70-9686-cf95b9d9f096
zzfmhu2j7ajq55mmpm3ihs3oqy c3264cef-1e5e-4c96-a192-26729539f3f5'''


@pytest.mark.usefixtures("op_session")
def test_get_by_custom_uuid(capsys):
    CliSimple('script', 'get', common_data('login_uuid'), 'title').run()
    std = capsys.readouterr()
    out_op_uuid = std.out
    CliSimple('script', 'get', common_data('login_custom_uuid'), 'title', '--use-custom-uuid').run()
    std2 = capsys.readouterr()
    out_custom_uuid = std2.out
    assert out_custom_uuid == out_op_uuid


@pytest.mark.usefixtures("op_session")
def test_mapping_list(capsys):
    CliSimple('script', 'mapping', 'update').run()
    CliSimple('script', 'mapping', 'list').run()
    std = capsys.readouterr()
    assert std.out == """zzfmhu2j7ajq55mmpm3ihs3oqy <-> c3264cef-1e5e-4c96-a192-26729539f3f5
smeg46sk3agiee4cfinvpf7z4u <-> 6bf1b272-f35d-4087-808f-253909fb0c91
a53bppwuhi65b2e34g45fjyfwu <-> c08335ad-5f93-471f-8605-2500ae4b9ce1
ngkzmk54qoltpdoseqspma4tba <-> 4dc2d37a-bc4e-47a8-a96b-206048b7d7d5
mvkzp2v2myljdqzxcv5736optu <-> b325bc32-7c2d-4107-bc2c-73777cb3e33a
w2euij3m4zhqa5opftnthe5d4q <-> f544c30d-612f-4c70-9686-cf95b9d9f096
n3iopimevz3pddels3dgfwyp2a <-> 41495d3a-9b1a-4ce6-9bbd-82fbc4e538a9
e25haqmocd5ifiymorfzwxnzry <-> 84103613-2483-430d-8e74-bc72036f378c
"""


@pytest.mark.usefixtures("no_op_session")
def test_not_authenticated(capsys):
    with pytest.raises(SystemExit) as exit_code:
        CliSimple('script', 'is-authenticated').run()
    std = capsys.readouterr()
    assert exit_code.type == SystemExit
    assert exit_code.value.code == 1


@pytest.mark.usefixtures("op_session")
def test_not_authenticated(capsys):
    CliSimple('script', 'is-authenticated').run()
    std = capsys.readouterr()
    assert std.out == ''



import pytest
from onepassword_local_search.tests.fixtures_common import storage_service, common_data


def test_item_query(storage_service):
    enc_item = storage_service.get_item_by_uuid(common_data('item_uuid'))
    assert enc_item['uuid'] == common_data('item_uuid')



from os import environ as os_environ, path as os_path
from json import load as json_load


class ConfigFileService:

    config: dict
    latest_signin: str

    def __init__(self):
        self.config = self._get_local_config()
        self.latest_signin = self.get_latest_signin()

    @staticmethod
    def _get_local_config():
        op_config_path = os_environ.get('ONEPASSWORD_CONFIG_FILE_PATH')
        if op_config_path:
            if not os_path.isfile(op_config_path):
                print('The env varialbe ONEPASSWORD_CONFIG_FILE_PATH speciies a missing file for OnePassword CLI configuration')
                exit(1)
        else:
            op_config_path = os_path.join(os_environ.get('HOME'), '.op', 'config')
        if not os_path.isfile(op_config_path):
            print('OnePassword CLI configuration is not present. Ensure you have run op signin')
            exit(1)
        with open(op_config_path) as op_config_file:
            return json_load(op_config_file)

    def get_latest_signin(self):
        if hasattr(self, 'latest_signin') and self.latest_signin:
            return self.latest_signin
        if not self.config.get('latest_signin'):
            print('Missing latest_signin information. Ensure you are sign in')
            exit(1)
        return self.config.get('latest_signin')

    def get_user_uuid(self):
        for account in self.config['accounts']:
            if account['shorthand'] != self.get_latest_signin():
                continue
            else:
                return account['userUUID']



import pytest
from onepassword_local_search.services.CryptoService import CryptoService
from onepassword_local_search.services.ConfigFileService import ConfigFileService
from onepassword_local_search.tests.fixtures_common import common_data, op_session, crypto_service
from onepassword_local_search.services.StorageService import StorageService
from onepassword_local_search.models.Item import Item
import os



@pytest.mark.usefixtures("op_session")
def test_session_keys(crypto_service):
    crypto_service._get_base_keys()
    assert crypto_service.sessionKey == common_data('session_key')
    assert type(crypto_service.encryptedSessionPrivateKey).__name__ == 'Cipher'
    assert crypto_service.encryptedSessionPrivateKey.iv == 'o86o5GT5zK7xh83e'
    assert crypto_service.encryptedSessionPrivateKey.data == 'Fn3jMEhlgsniiwP0wgSUF-HUR2LHEQuIW032Oz25VokclJG9t2Tl8a8KgDHgVwgypO2hQbS_0u2xteDEON4GVV7vf4C_7UmzbWIaz5qN1PXa5_AlnmBmHiRFXoTNEQgqJqxkEDHGnCaNExkw8FenArevjwKwp2Zwr1jIL0m8YVEnROSKg8WEuuOh74EehpkmypBJ-I4PIHe-C80OwqriwK6XK_3dEat6iYzvSYKQK4MwY5eTDSZWoIvaAFs8QHBez8CiaDmzIp1fgNOiYwplf9skc9ZA0cvUc9i0AT3aQa7PBsTHEQ2srgF43sS4eFF6X66QOmsbY4UAy-JjakOmIPkthkkx5dsGIsCUO1whAzIlmnTrNYUFtA'
    assert crypto_service.encryptedSessionPrivateKey.enc == 'A256GCM'
    assert crypto_service.sessionPrivateKey['encodedMuk'] == '2Zqlkn-ppcrz0RaH3wDUiKwu1YUPj1bRM09R9MEmsrE'
    assert crypto_service.sessionPrivateKey['encodedKey'] == 'JH84cS3eNebV8P0Kck3fviRSfnOk8WMFUtiF6umWHFY'

@pytest.mark.usefixtures("op_session")
def test_keyset(crypto_service):
    crypto_service._get_base_keys()
    assert crypto_service.symmetricKey['alg'] == 'A256GCM'
    assert crypto_service.symmetricKey['k'] == 'DTCXfnskB1Sm8QiMA_qCWxwZ4GmWOeyAreSN8c0pRcc'

@pytest.mark.usefixtures("op_session")
def test_private_key(crypto_service):
    crypto_service._get_base_keys()
    assert crypto_service.privateKey['alg'] == 'RSA-OAEP'
    assert crypto_service.privateKey['kid'] == 'vhhhcyj7rc3vocnd5o2iksiflm'
    assert crypto_service.privateKey['n'] == 'vOAZ3IwHI1bkkD5L_5uGvrtMV6KKjzK55ed02Tbqa5Z9k4tKNiwIMykNzmR3XSsNRRthQE6llIh8AJLCbypGnEuCKWZDYmkW_42dF26VjUQ5WqEdWniypsDBcSFqQzBbbb6yv_gs0FNG5QpsEBRuA5DeFSh86CSW-BY35GaARo1G9zDKoqyEI6vZGGX3gv9Nr0docD1Y8ducwkAPtFX4fhFTiBpvJeAGzlKk6imeknZiC4hDFOFt07_vJqORB4Y1crrixPE5E6xkutzgui3WdXBjL14RPIxgfT3_zwc_3Uyy71Y3Tr99MA-i2iWVpRDj9GS3lXh8m9ABp4O4AnU7YQ'

@pytest.mark.usefixtures("op_session")
def test_vault_key(crypto_service):
    vault_key = crypto_service._get_vault_key('6')
    assert vault_key['alg'] == 'A256GCM'
    assert vault_key['k'] == 'CF6mPDqu8Uklk2tfq4Vj5moILWpdxKZycIxQI1VUg1A'

@pytest.mark.usefixtures("op_session")
def test_vault_key(crypto_service):
    item = crypto_service.decrypt_item(Item(crypto_service.storageService.get_item_by_uuid(common_data('item_uuid'))))
    assert item.overview['title'] == 'Software licence'
    assert item.details['sections'][0]['fields'][1]['v'] == 'License number'

@pytest.mark.usefixtures("op_session")
def test_get_encrypted_session_file_path(crypto_service, monkeypatch):
    monkeypatch.delenv('OP_SESSION_PRIVATE_KEY_FILE')
    assert crypto_service._get_encrypted_session_file_path() == os.path.join(os.path.dirname(os.path.dirname(__file__)), 'tests', '.Y_efcm4Gd_W4NnRTMeOuSEHPA5w')